@@ -4,6 +4,9 @@
 import argparse
 import logging
 import sys
+import threading
+
+import systemd.daemon
 
 from . import __version__
 from . import app as app_module
@@ -95,6 +98,22 @@ def on_web_server_stop():
     glib.stop()
 
 
+def run_post_init_and_setup():
+    """Run post-init operations on the apps and setup operations."""
+    app_module.apps_post_init()
+    frontpage.add_custom_shortcuts()
+
+    # Handle app version updates.
+    setup.run_setup_on_startup()  # Long running, retrying
+
+    # Handle packages that have been updated else where that need a re-run of
+    # setup.
+    setup.on_dpkg_invoked()
+
+    # Handle packages that have a pending configuration file prompt.
+    setup.on_package_cache_updated()
+
+
 def main():
     """Initialize and start the application"""
     arguments = parse_arguments()
@@ -134,22 +153,28 @@ def main():
 
     module_loader.load_modules()
     app_module.apps_init()
-    app_module.apps_post_init()
-    frontpage.add_custom_shortcuts()
 
     if arguments.setup is not False:
+        app_module.apps_post_init()
         run_setup_and_exit(arguments.setup, allow_install=True)
 
     if arguments.setup_no_install is not False:
+        app_module.apps_post_init()
         run_setup_and_exit(arguments.setup_no_install, allow_install=False)
 
-    setup.run_setup_in_background()
+    threading.Thread(target=run_post_init_and_setup).start()
 
     glib.run()
 
     web_server.init()
     web_server.run(on_web_server_stop)
 
+    # systemd will wait until notification to proceed with other processes. We
+    # have service Type=notify.
+    systemd.daemon.notify('READY=1')
+
+    web_server.block()
+
 
 if __name__ == '__main__':
     main()
