@@ -13,10 +13,15 @@ class ApiApp(app_module.App):
 
     _version = 1
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Create components for the app."""
         super().__init__()
 
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                is_essential=True)
         self.add(info)
+
+    def setup(self, old_version):
+        """Install and configure the app."""
+        super().setup(old_version)
+        self.enable()
