@@ -74,9 +74,11 @@ class DynamicDNSApp(app_module.App):
         enable_state = app_module.EnableState('enable-state-dynamicdns')
         self.add(enable_state)
 
-        domain_type = DomainType('domain-type-dynamic',
-                                 _('Dynamic Domain Name'), 'dynamicdns:index',
-                                 can_have_certificate=True)
+        domain_type = DomainType('domain-type-dynamic', _('Dynamic Domain'),
+                                 edit_url='dynamicdns:domain-edit',
+                                 delete_url='dynamicdns:domain-delete',
+                                 add_url='dynamicdns:domain-add',
+                                 can_have_certificate=True, priority=70)
         self.add(domain_type)
 
         users_and_groups = UsersAndGroups('users-and-groups-dynamicdns',
@@ -97,6 +99,21 @@ class DynamicDNSApp(app_module.App):
         # Check every 5 minutes to perform dynamic DNS updates.
         glib.schedule(300, update_dns)
 
+    def enable(self):
+        """Send domain signals after enabling the app."""
+        super().enable()
+        config = get_config()
+        for domain_name in config['domains']:
+            notify_domain_added(domain_name)
+
+    def disable(self):
+        """Send domain signals before disabling the app."""
+        config = get_config()
+        for domain_name in config['domains']:
+            notify_domain_removed(domain_name)
+
+        super().disable()
+
     def setup(self, old_version):
         """Install and configure the app."""
         super().setup(old_version)
@@ -224,6 +241,20 @@ def get_status():
     status = kvstore.get_default('dynamicdns_status', '{}')
     status = json.loads(status)
     status.setdefault('domains', {})
+
+    domains = get_config()['domains']
+    for domain in domains:
+        if domain not in status['domains']:
+            # No status available for newly configured domain
+            status['domains'][domain] = {
+                'domain': domain,
+                'result': False,
+                'ip_address': None,
+                'error_code': None,
+                'error_message': None,
+                'timestamp': 0,
+            }
+
     return status
 
 
@@ -268,13 +299,15 @@ def set_config(config):
 
 def notify_domain_added(domain_name):
     """Send a signal that domain has been added."""
-    domain_added.send_robust(sender='dynamicdns',
-                             domain_type='domain-type-dynamic',
-                             name=domain_name, services='__all__')
+    if app_module.App.get('dynamicdns').is_enabled():
+        domain_added.send_robust(sender='dynamicdns',
+                                 domain_type='domain-type-dynamic',
+                                 name=domain_name, services='__all__')
 
 
 def notify_domain_removed(domain_name):
     """Send a signal that domain has been removed."""
-    domain_removed.send_robust(sender='dynamicdns',
-                               domain_type='domain-type-dynamic',
-                               name=domain_name)
+    if app_module.App.get('dynamicdns').is_enabled():
+        domain_removed.send_robust(sender='dynamicdns',
+                                   domain_type='domain-type-dynamic',
+                                   name=domain_name)
