@@ -3,7 +3,7 @@
 URLs for the JSXC module
 """
 
-from django.conf.urls import url
+from django.urls import re_path
 from stronghold.decorators import public
 
 from plinth.views import AppView
@@ -11,6 +11,6 @@ from plinth.views import AppView
 from .views import JsxcView
 
 urlpatterns = [
-    url(r'^apps/jsxc/$', AppView.as_view(app_id='jsxc'), name='index'),
-    url(r'^apps/jsxc/jsxc/$', public(JsxcView.as_view()), name='jsxc')
+    re_path(r'^apps/jsxc/$', AppView.as_view(app_id='jsxc'), name='index'),
+    re_path(r'^apps/jsxc/jsxc/$', public(JsxcView.as_view()), name='jsxc')
 ]
