@@ -4,7 +4,7 @@ Forms for minetest module.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class MinetestForm(forms.Form):
