@@ -7,4 +7,4 @@ from . import privileged
 
 backup = {'config': {'files': [str(privileged.CONFIG_FILE)]}}
 
-tags = [_('Usage reporting'), _('Fallback DNS')]
+tags = [_('Usage reporting'), _('External services'), _('Fallback DNS')]
